@@ -23,8 +23,11 @@
 #include <utility>
 #include <cairomm/surface.h>
 #include <cairomm/fontface.h>
+#include <cairomm/matrix.h>
 #include <cairomm/pattern.h>
 #include <cairomm/path.h>
+#include <cairomm/scaledfont.h>
+#include <cairomm/types.h>
 #include <valarray>
 #include <vector>
 #include <cairo.h>
@@ -33,12 +36,6 @@
 namespace Cairo
 {
 
-typedef cairo_glyph_t Glyph; //A simple struct.
-typedef cairo_font_extents_t FontExtents; //A simple struct.
-typedef cairo_text_extents_t TextExtents; //A simple struct.
-typedef cairo_matrix_t Matrix; //A simple struct. //TODO: Derive and add operator[] and operator. matrix multiplication?
-typedef cairo_rectangle_t Rectangle;
-
 /** Context is the main class used to draw in cairomm. 
  * In the simplest case, create a Context with its target Surface, set its
  * drawing options (line width, color, etc), create shapes with methods like
@@ -163,9 +160,9 @@ public:
    * attributes can be modified if desired, (eg. to create a repeating pattern
    * with Pattern::set_extend()).
    *
-   * @param surface : 	a Surface to be used to set the source pattern
-   * @param x : 	User-space X coordinate for surface origin
-   * @param y : 	User-space Y coordinate for surface origin 
+   * @param surface  	a Surface to be used to set the source pattern
+   * @param x  	User-space X coordinate for surface origin
+   * @param y  	User-space Y coordinate for surface origin 
    */
   void set_source(const RefPtr<Surface>& surface, double x, double y);
 
@@ -310,6 +307,9 @@ public:
    */
   void transform(const Matrix& matrix);
 
+  /* To keep 1.6.x ABI  */
+  void transform(const cairo_matrix_t& matrix);
+
   /** Modifies the current transformation matrix (CTM) by setting it equal to
    * matrix.
    *
@@ -317,6 +317,9 @@ public:
    */
   void set_matrix(const Matrix& matrix);
 
+  /* To keep 1.6.x ABI  */
+  void set_matrix(const cairo_matrix_t& matrix);
+
   /** Resets the current transformation matrix (CTM) by setting it equal to the
    * identity matrix. That is, the user-space and device-space axes will be
    * aligned and one user-space unit will transform to one device-space unit.
@@ -705,10 +708,41 @@ public:
   void set_font_matrix(const Matrix& matrix);
   void get_font_matrix(Matrix& matrix) const;
   void set_font_options(const FontOptions& options);
+
+  /* To keep 1.6.x ABI  */
+  void set_font_matrix(const cairo_matrix_t& matrix);
+  void get_font_matrix(cairo_matrix_t& matrix) const;
+
+  //TODO: Documentation.
+  /**
+   * @since 1.8
+   */
+  void get_font_options(FontOptions& options) const;
+
+  //TODO: Documentation.
+  /**
+   * @since 1.8
+   */
+  void set_scaled_font(const RefPtr<const ScaledFont>& scaled_font);
+
+  //TODO: Documentation.
+  /**
+   * @since 1.8
+   */
+  RefPtr<ScaledFont> get_scaled_font();
+
+  //TODO: Documentation:
   void show_text(const std::string& utf8);
   void show_glyphs(const std::vector<Glyph>& glyphs);
+  /** @since 1.8 */
+  void show_text_glyphs(const std::string& utf8,
+                        const std::vector<Glyph>& glyphs,
+                        const std::vector<TextCluster>& clusters,
+                        TextClusterFlags cluster_flags);
+
   RefPtr<FontFace> get_font_face();
   RefPtr<const FontFace> get_font_face() const;
+
   void get_font_extents(FontExtents& extents) const;
   void set_font_face(const RefPtr<const FontFace>& font_face);
   void get_text_extents(const std::string& utf8, TextExtents& extents) const;
@@ -746,9 +780,15 @@ public:
    *
    * @param x	return value for X coordinate of the current point
    * @param y	return value for Y coordinate of the current point
+   *
+   * @see has_current_point
    */
   void get_current_point (double& x, double& y) const;
 
+  /** Checks if there is a current point defined
+   */
+  bool has_current_point() const;
+
   /** Gets the current fill rule, as set by set_fill_rule().
    */
   FillRule get_fill_rule() const;
@@ -772,8 +812,8 @@ public:
   /**
    * Gets the current dash array and offset.
    *
-   * @param dashes return value for the dash array
-   * @param offset return value for the current dash offset
+   * @param dashes return value for the dash array.
+   * @param offset return value for the current dash offset.
    *
    * Since: 1.4
    **/
@@ -786,6 +826,13 @@ public:
    */
   void get_matrix(Matrix& matrix);
 
+  /* To keep 1.6.x ABI  */
+  void get_matrix(cairo_matrix_t& matrix);
+
+  /** @since 1.8
+   */
+  Matrix get_matrix() const;
+
   /** Gets the target surface associated with this Context.
    *
    * @exception
@@ -809,6 +856,36 @@ public:
    */
   Path* copy_path() const;
 
+/**
+ * Computes a bounding box in user-space coordinates covering the points on
+ * the current path. If the current path is empty, returns an empty rectangle
+ * ((0,0), (0,0)). Stroke parameters, fill rule, surface dimensions and
+ * clipping are not taken into account.
+ *
+ * Contrast with fill_extents() and stroke_extents() which return the extents
+ * of only the area that would be "inked" by the corresponding drawing
+ * operations.
+ *
+ * The result of path_extents() is defined as equivalent to the limit of
+ * stroke_extents() with Cairo::LINE_CAP_ROUND as the line width approaches
+ * 0.0, (but never reaching the empty-rectangle returned by stroke_extents()
+ * for a line width of 0.0).
+ *
+ * Specifically, this means that zero-area sub-paths such as
+ * move_to();line_to() segments, (even degenerate cases where the coordinates
+ * to both calls are identical), will be considered as contributing to the
+ * extents. However, a lone move_to() will not contribute to the results of
+ * path_extents().
+ *
+ * @param x1 left of the resulting extents
+ * @param y1 top of the resulting extents
+ * @param x2 right of the resulting extents
+ * @param y2 bottom of the resulting extents
+ *
+ * @since 1.6
+ **/
+  void get_path_extents(double& x1, double& y1, double& x2, double& y2) const;
+
   /** Gets a flattened copy of the current path and returns it to the user
    *
    * @todo See cairo_path_data_t for hints on how to iterate over the returned
@@ -883,7 +960,7 @@ public:
    * content type is the only distinction between this function and push_group()
    * which you should see for a more detailed description of group rendering.
    *
-   * @param content: indicates the type of group that will be created
+   * @param content indicates the type of group that will be created
    */
   void push_group_with_content(Content content);
 
